"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _MutualAuthentication = _interopRequireDefault(require("../model/MutualAuthentication"));

var _MutualAuthenticationResponse = _interopRequireDefault(require("../model/MutualAuthenticationResponse"));

var _MutualAuthenticationsResponse = _interopRequireDefault(require("../model/MutualAuthenticationsResponse"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
* MutualAuthentication service.
* @module api/MutualAuthenticationApi
* @version 3.0.0
*/
var MutualAuthenticationApi = /*#__PURE__*/function () {
  /**
  * Constructs a new MutualAuthenticationApi. 
  * @alias module:api/MutualAuthenticationApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function MutualAuthenticationApi(apiClient) {
    _classCallCheck(this, MutualAuthenticationApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;

    if (typeof window === 'undefined' && Boolean(process.env.FASTLY_API_TOKEN)) {
      this.apiClient.authenticate(process.env.FASTLY_API_TOKEN);
    }
  }
  /**
   * Create a mutual authentication using a bundle of certificates to enable client-to-server mutual TLS.
   * @param {Object} options
   * @param {module:model/MutualAuthentication} [options.mutual_authentication]
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/MutualAuthenticationResponse} and HTTP response
   */


  _createClass(MutualAuthenticationApi, [{
    key: "createMutualTlsAuthenticationWithHttpInfo",
    value: function createMutualTlsAuthenticationWithHttpInfo() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var postBody = options['mutual_authentication'];
      var pathParams = {};
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['token'];
      var contentTypes = ['application/vnd.api+json'];
      var accepts = ['application/vnd.api+json'];
      var returnType = _MutualAuthenticationResponse["default"];
      return this.apiClient.callApi('/tls/mutual_authentications', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Create a mutual authentication using a bundle of certificates to enable client-to-server mutual TLS.
     * @param {Object} options
     * @param {module:model/MutualAuthentication} [options.mutual_authentication]
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/MutualAuthenticationResponse}
     */

  }, {
    key: "createMutualTlsAuthentication",
    value: function createMutualTlsAuthentication() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return this.createMutualTlsAuthenticationWithHttpInfo(options).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Remove a Mutual TLS authentication
     * @param {Object} options
     * @param {String} options.mutual_authentication_id - Alphanumeric string identifying a mutual authentication.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing HTTP response
     */

  }, {
    key: "deleteMutualTlsWithHttpInfo",
    value: function deleteMutualTlsWithHttpInfo() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var postBody = null; // Verify the required parameter 'mutual_authentication_id' is set.

      if (options['mutual_authentication_id'] === undefined || options['mutual_authentication_id'] === null) {
        throw new Error("Missing the required parameter 'mutual_authentication_id'.");
      }

      var pathParams = {
        'mutual_authentication_id': options['mutual_authentication_id']
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['token'];
      var contentTypes = [];
      var accepts = [];
      var returnType = null;
      return this.apiClient.callApi('/tls/mutual_authentications/{mutual_authentication_id}', 'DELETE', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Remove a Mutual TLS authentication
     * @param {Object} options
     * @param {String} options.mutual_authentication_id - Alphanumeric string identifying a mutual authentication.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}
     */

  }, {
    key: "deleteMutualTls",
    value: function deleteMutualTls() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return this.deleteMutualTlsWithHttpInfo(options).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Show a Mutual Authentication.
     * @param {Object} options
     * @param {String} options.mutual_authentication_id - Alphanumeric string identifying a mutual authentication.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/MutualAuthenticationResponse} and HTTP response
     */

  }, {
    key: "getMutualAuthenticationWithHttpInfo",
    value: function getMutualAuthenticationWithHttpInfo() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var postBody = null; // Verify the required parameter 'mutual_authentication_id' is set.

      if (options['mutual_authentication_id'] === undefined || options['mutual_authentication_id'] === null) {
        throw new Error("Missing the required parameter 'mutual_authentication_id'.");
      }

      var pathParams = {
        'mutual_authentication_id': options['mutual_authentication_id']
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['token'];
      var contentTypes = [];
      var accepts = ['application/vnd.api+json'];
      var returnType = _MutualAuthenticationResponse["default"];
      return this.apiClient.callApi('/tls/mutual_authentications/{mutual_authentication_id}', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Show a Mutual Authentication.
     * @param {Object} options
     * @param {String} options.mutual_authentication_id - Alphanumeric string identifying a mutual authentication.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/MutualAuthenticationResponse}
     */

  }, {
    key: "getMutualAuthentication",
    value: function getMutualAuthentication() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return this.getMutualAuthenticationWithHttpInfo(options).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * List all mutual authentications.
     * @param {Object} options
     * @param {Number} [options.page_number] - Current page.
     * @param {Number} [options.page_size=20] - Number of records per page.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/MutualAuthenticationsResponse} and HTTP response
     */

  }, {
    key: "listMutualAuthenticationsWithHttpInfo",
    value: function listMutualAuthenticationsWithHttpInfo() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var postBody = null;
      var pathParams = {};
      var queryParams = {
        'page[number]': options['page_number'],
        'page[size]': options['page_size']
      };
      var headerParams = {};
      var formParams = {};
      var authNames = ['token'];
      var contentTypes = [];
      var accepts = ['application/vnd.api+json'];
      var returnType = _MutualAuthenticationsResponse["default"];
      return this.apiClient.callApi('/tls/mutual_authentications', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * List all mutual authentications.
     * @param {Object} options
     * @param {Number} [options.page_number] - Current page.
     * @param {Number} [options.page_size=20] - Number of records per page.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/MutualAuthenticationsResponse}
     */

  }, {
    key: "listMutualAuthentications",
    value: function listMutualAuthentications() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return this.listMutualAuthenticationsWithHttpInfo(options).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Update a Mutual Authentication.
     * @param {Object} options
     * @param {String} options.mutual_authentication_id - Alphanumeric string identifying a mutual authentication.
     * @param {module:model/MutualAuthentication} [options.mutual_authentication]
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/MutualAuthenticationResponse} and HTTP response
     */

  }, {
    key: "patchMutualAuthenticationWithHttpInfo",
    value: function patchMutualAuthenticationWithHttpInfo() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var postBody = options['mutual_authentication']; // Verify the required parameter 'mutual_authentication_id' is set.

      if (options['mutual_authentication_id'] === undefined || options['mutual_authentication_id'] === null) {
        throw new Error("Missing the required parameter 'mutual_authentication_id'.");
      }

      var pathParams = {
        'mutual_authentication_id': options['mutual_authentication_id']
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['token'];
      var contentTypes = ['application/vnd.api+json'];
      var accepts = ['application/vnd.api+json'];
      var returnType = _MutualAuthenticationResponse["default"];
      return this.apiClient.callApi('/tls/mutual_authentications/{mutual_authentication_id}', 'PATCH', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Update a Mutual Authentication.
     * @param {Object} options
     * @param {String} options.mutual_authentication_id - Alphanumeric string identifying a mutual authentication.
     * @param {module:model/MutualAuthentication} [options.mutual_authentication]
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/MutualAuthenticationResponse}
     */

  }, {
    key: "patchMutualAuthentication",
    value: function patchMutualAuthentication() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return this.patchMutualAuthenticationWithHttpInfo(options).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return MutualAuthenticationApi;
}();

exports["default"] = MutualAuthenticationApi;